==> enterprisemodules-ovm_config-1.0.5.tar.gz: enterprisemodules-ovm_config-1.0.5/lib/puppet/type/ovm_vm/network_adapters.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:network_adapters, :parent => Puppet::Parameter::OvmProperty) do
  include Puppet_X::EnterpriseModules::Ovm::Data

  desc <<-EOD
  Specifies Network Adapters for Oracle Virtual Machine.
  Here is example how to do this:

      ovm_vm { 'default/mypool1/ovmserver1.example.com:myvm2':
        ...
        network_adapters        => {
          '00:21:f6:87:bf:2a' => {
            'mac_address' => '00:21:f6:87:bf:2a',
            'network_name' => '192.168.56.0',
            'description' => 'vnic 1'
          },
          'adapter_2' => {
            'mac_address' => '00:21:f6:87:bf:2a',
            'network_name' => '192.168.56.0',
            'description' => 'vnic 2'
          }
        }
        ...
      }

  EOD

  def self.translate_to_resource(raw_resource)
    manager = raw_resource.fetch('manager')
    hash = {}
    raw_resource['virtualNicIds'].each do |vnic_id|
      hash_name        = vnic_id['name']
      virtual_nic_info = virtual_nic_data(vnic_id['value'], manager: manager)
      hash[hash_name] = {
        'mac_address'  => virtual_nic_info['macAddress'],
        'network_name' => virtual_nic_info['networkId']['name'],
        'description'  => virtual_nic_info['description']
      }
    end
    hash
  end

  on_apply do
    vm_id            = vm_id_for(resource.vm_name)
    network_adapters = resource.network_adapters
    # Create virtual nic for given network
    add_vnics(vm_id, network_adapters)
  end

  defaultto({})

  private

  def add_vnics(vm_id, network_adapters)
    all_networks = network_data
    fail 'No network are present' if all_networks.empty?

    with_manager_connection do |connection|
      path = "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/Vm/#{vm_id['value']}/VirtualNic"
      network_adapters.each do |key, adapter|
        payload = Hash.new.tap do |vnic_obj|
          vnic_obj['name']       = key
          vnic_obj['networkId']  = find_network_id(all_networks, adapter['network_name'])
          vnic_obj['macAddress'] = adapter['mac_address'] if adapter['mac_address']
        end
        connection.validated(:post, path, payload)
      end
      connection.get(path).body
    end
  end

  def find_network_id(networks, network_name)
    network = networks.find { |n| n['id']['name'] == network_name }
    fail "Network with name: #{network_name} is not found." unless network
    network['id']
  end
end

==> enterprisemodules-ovm_config-1.1.0.tar.gz: enterprisemodules-ovm_config-1.1.0/lib/puppet/type/ovm_vm/network_adapters.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:network_adapters, :parent => Puppet::Parameter::OvmProperty) do
  include Puppet_X::EnterpriseModules::Ovm::Data

  desc <<-DOCS
  Specifies Network Adapters for Oracle Virtual Machine.
  Here is example how to do this:

      ovm_vm { 'default/mypool1/ovmserver1.example.com:myvm2':
        ...
        network_adapters        => {
          '00:21:f6:87:bf:2a' => {
            'mac_address' => '00:21:f6:87:bf:2a',
            'network_name' => '192.168.56.0',
            'description' => 'vnic 1'
          },
          'adapter_2' => {
            'mac_address' => '00:21:f6:87:bf:2a',
            'network_name' => '192.168.56.0',
            'description' => 'vnic 2'
          }
        }
        ...
      }

  DOCS

  def self.translate_to_resource(raw_resource)
    manager = raw_resource.fetch('manager')
    hash = {}
    raw_resource['virtualNicIds'].each do |vnic_id|
      hash_name        = vnic_id['name']
      virtual_nic_info = virtual_nic_data(vnic_id['value'], :manager => manager)
      hash[hash_name] = {
        'mac_address' => virtual_nic_info['macAddress'],
        'network_name' => virtual_nic_info.dig('networkId', 'name'),
        'description' => virtual_nic_info['description']
      }
    end
    hash
  end

  on_apply do
    vm_id            = vm_id_for(resource.vm_name)
    network_adapters = resource.network_adapters
    # Create virtual nic for given network
    add_vnics(vm_id, network_adapters)
  end

  defaultto({})

  private

  def add_vnics(vm_id, network_adapters)
    all_networks = network_data
    fail 'No network are present' if all_networks.empty?

    with_manager_connection do |connection|
      path = "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/Vm/#{vm_id['value']}/VirtualNic"
      network_adapters.each do |key, adapter|
        connection.validated(:post, path, payload(all_networks, key, adapter))
      end
      connection.get(path).body
    end
  end

  def payload(all_networks, key, adapter)
    {}.tap do |vnic_obj|
      vnic_obj['name']       = key
      vnic_obj['networkId']  = find_network_id(all_networks, adapter['network_name'])
      vnic_obj['macAddress'] = adapter['mac_address'] if adapter['mac_address']
    end
  end

  def find_network_id(networks, network_name)
    network = networks.find { |n| n.dig('id', 'name') == network_name }
    fail "Network with name: #{network_name} is not found." unless network

    network['id']
  end
end
